@@ -13,15 +13,17 @@
 """Account management related classes and functions."""
 
 import os
+import ast
 from typing import Optional, Dict
 from .exceptions import AccountNotFoundError
 from .account import Account, ChannelType
 from ..proxies import ProxyConfiguration
-from .storage import save_config, read_config, delete_config
+from .storage import save_config, read_config, delete_config, read_qiskitrc
 
 _DEFAULT_ACCOUNT_CONFIG_JSON_FILE = os.path.join(
     os.path.expanduser("~"), ".qiskit", "qiskit-ibm.json"
 )
+_QISKITRC_CONFIG_FILE = os.path.join(os.path.expanduser("~"), ".qiskit", "qiskitrc")
 _DEFAULT_ACCOUNT_NAME = "default"
 _DEFAULT_ACCOUNT_NAME_LEGACY = "default-legacy"
 _DEFAULT_ACCOUNT_NAME_CLOUD = "default-cloud"
@@ -163,6 +165,33 @@ class AccountManager:
             if account_name in all_config:
                 return Account.from_saved_format(all_config[account_name])
 
+        if os.path.isfile(_QISKITRC_CONFIG_FILE):
+            qiskitrc_data = read_qiskitrc(_QISKITRC_CONFIG_FILE)
+            proxies = (
+                ProxyConfiguration(ast.literal_eval(qiskitrc_data["proxies"]))
+                if "proxies" in qiskitrc_data
+                else None
+            )
+            save_config(
+                filename=_DEFAULT_ACCOUNT_CONFIG_JSON_FILE,
+                name=_DEFAULT_ACCOUNT_NAME_IBM_QUANTUM,
+                overwrite=False,
+                config=Account(
+                    token=qiskitrc_data.get("token", None),
+                    url=qiskitrc_data.get("url", None),
+                    instance=qiskitrc_data.get("default_provider", None),
+                    verify=bool(qiskitrc_data.get("verify", None)),
+                    proxies=proxies,
+                    channel="ibm_quantum",
+                )
+                .validate()
+                .to_saved_format(),
+            )
+            default_config = read_config(filename=_DEFAULT_ACCOUNT_CONFIG_JSON_FILE)
+            return Account.from_saved_format(
+                default_config[_DEFAULT_ACCOUNT_NAME_IBM_QUANTUM]
+            )
+
         raise AccountNotFoundError("Unable to find account.")
 
     @classmethod
