@@ -15,7 +15,7 @@
 from typing import Dict, Optional, Any, Union
 
 from ..utils import get_runtime_api_base_url
-from ..api.auth import LegacyAuth, CloudAuth
+from ..api.auth import QuantumAuth, CloudAuth
 from ..proxies import ProxyConfiguration
 
 TEMPLATE_IBM_HUBS = "{prefix}/Network/{hub}/Groups/{group}/Projects/{project}"
@@ -27,7 +27,7 @@ class ClientParameters:
 
     def __init__(
         self,
-        auth_type: str,
+        channel: str,
         token: str,
         url: str = None,
         instance: Optional[str] = None,
@@ -37,7 +37,7 @@ class ClientParameters:
         """ClientParameters constructor.
 
         Args:
-            auth_type: Authentication type. ``cloud`` or ``legacy``.
+            channel: Channel type. ``ibm_cloud`` or ``ibm_quantum``.
             token: IBM Quantum API token.
             url: IBM Quantum URL (gets replaced with a new-style URL with hub, group, project).
             instance: Service instance to use.
@@ -46,17 +46,17 @@ class ClientParameters:
         """
         self.token = token
         self.instance = instance
-        self.auth_type = auth_type
+        self.channel = channel
         self.url = url
         self.proxies = proxies
         self.verify = verify
 
-    def get_auth_handler(self) -> Union[CloudAuth, LegacyAuth]:
+    def get_auth_handler(self) -> Union[CloudAuth, QuantumAuth]:
         """Returns the respective authentication handler."""
-        if self.auth_type == "cloud":
+        if self.channel == "ibm_cloud":
             return CloudAuth(api_key=self.token, crn=self.instance)
 
-        return LegacyAuth(access_token=self.token)
+        return QuantumAuth(access_token=self.token)
 
     def get_runtime_api_base_url(self) -> str:
         """Returns the Runtime API base url."""
