@@ -122,6 +122,9 @@ class RuntimeClient(BaseBackendClient):
         hgp: Optional[str],
         log_level: Optional[str],
         session_id: Optional[str],
+        job_tags: Optional[List[str]] = None,
+        max_execution_time: Optional[int] = None,
+        start_session: Optional[bool] = False,
     ) -> Dict:
         """Run the specified program.
 
@@ -133,6 +136,9 @@ class RuntimeClient(BaseBackendClient):
             hgp: Hub/group/project to use.
             log_level: Log level to use.
             session_id: Job ID of the first job in a runtime session.
+            job_tags: Tags to be assigned to the job.
+            max_execution_time: Maximum execution time in seconds.
+            start_session: Set to True to explicitly start a runtime session. Defaults to False.
 
         Returns:
             JSON response.
@@ -148,6 +154,9 @@ class RuntimeClient(BaseBackendClient):
             image=image,
             log_level=log_level,
             session_id=session_id,
+            job_tags=job_tags,
+            max_execution_time=max_execution_time,
+            start_session=start_session,
             **hgp_dict
         )
 
@@ -211,6 +220,11 @@ class RuntimeClient(BaseBackendClient):
         hub: str = None,
         group: str = None,
         project: str = None,
+        job_tags: Optional[List[str]] = None,
+        session_id: Optional[str] = None,
+        created_after: Optional[python_datetime] = None,
+        created_before: Optional[python_datetime] = None,
+        descending: bool = True,
     ) -> Dict:
         """Get job data for all jobs.
 
@@ -223,6 +237,16 @@ class RuntimeClient(BaseBackendClient):
             hub: Filter by hub - hub, group, and project must all be specified.
             group: Filter by group - hub, group, and project must all be specified.
             project: Filter by project - hub, group, and project must all be specified.
+            job_tags: Filter by tags assigned to jobs. Matched jobs are associated with all tags.
+            session_id: Job ID of the first job in a runtime session.
+            created_after: Filter by the given start date, in local time. This is used to
+                find jobs whose creation dates are after (greater than or equal to) this
+                local date/time.
+            created_before: Filter by the given end date, in local time. This is used to
+                find jobs whose creation dates are before (less than or equal to) this
+                local date/time.
+            descending: If ``True``, return the jobs in descending order of the job
+                creation date (i.e. newest first) until the limit is reached.
 
         Returns:
             JSON response.
@@ -235,6 +259,11 @@ class RuntimeClient(BaseBackendClient):
             hub=hub,
             group=group,
             project=project,
+            job_tags=job_tags,
+            session_id=session_id,
+            created_after=created_after,
+            created_before=created_before,
+            descending=descending,
         )
 
     def job_results(self, job_id: str) -> str:
@@ -286,6 +315,14 @@ class RuntimeClient(BaseBackendClient):
         """
         return self._api.program_job(job_id).logs()
 
+    def close_session(self, session_id: str) -> None:
+        """Close the runtime session.
+
+        Args:
+            session_id: Session ID.
+        """
+        self._api.runtime_session(session_id=session_id).close()
+
     # IBM Cloud only functions
 
     def list_backends(self) -> List[str]:
