@@ -26,6 +26,7 @@ from urllib3.util.retry import Retry
 from qiskit_ibm_runtime.utils.utils import filter_data
 
 from .exceptions import RequestsApiError
+from ..exceptions import IBMNotAuthorizedError
 from ..version import __version__ as ibm_runtime_version
 
 STATUS_FORCELIST = (
@@ -40,11 +41,11 @@ STATUS_FORCELIST = (
 )
 CUSTOM_HEADER_ENV_VAR = "QISKIT_IBM_RUNTIME_CUSTOM_CLIENT_APP_HEADER"
 logger = logging.getLogger(__name__)
-# Regex used to match the `/devices` endpoint, capturing the device name as group(2).
+# Regex used to match the `/backends` endpoint, capturing the device name as group(2).
 # The number of letters for group(2) must be greater than 1, so it does not match
 # the `/devices/v/1` endpoint.
-# Capture groups: (/devices/)(<device_name>)(</optional rest of the url>)
-RE_DEVICES_ENDPOINT = re.compile(r"^(.*/devices/)([^/}]{2,})(.*)$", re.IGNORECASE)
+# Capture groups: (/backends/)(<device_name>)(</optional rest of the url>)
+RE_BACKENDS_ENDPOINT = re.compile(r"^(.*/backends/)([^/}]{2,})(.*)$", re.IGNORECASE)
 
 
 def _get_client_header() -> str:
@@ -241,6 +242,7 @@ class RetrySession(Session):
 
         Raises:
             RequestsApiError: If the request failed.
+            IBMNotAuthorizedError: If the auth token is invalid.
         """
         # pylint: disable=arguments-differ
         if bare:
@@ -282,7 +284,8 @@ class RetrySession(Session):
                 except Exception:  # pylint: disable=broad-except
                     # the response did not contain the expected json.
                     message += f". {ex.response.text}"
-
+            if status_code == 401:
+                raise IBMNotAuthorizedError(message) from ex
             raise RequestsApiError(message, status_code) from ex
 
         return response
@@ -300,7 +303,7 @@ class RetrySession(Session):
 
             The request data is only logged for the following URLs, since they contain useful
             information: ``/Jobs`` (POST), ``/Jobs/status`` (GET),
-            and ``/devices/<device_name>/properties`` (GET).
+            and ``/backends/<device_name>/properties`` (GET).
 
         Args:
             url: URL for the new request.
@@ -311,7 +314,7 @@ class RetrySession(Session):
             Exception: If there was an error logging the request information.
         """
         # Replace the device name in the URL with `...` if it matches, otherwise leave it as is.
-        filtered_url = re.sub(RE_DEVICES_ENDPOINT, "\\1...\\3", url)
+        filtered_url = re.sub(RE_BACKENDS_ENDPOINT, "\\1...\\3", url)
 
         if self._is_worth_logging(filtered_url):
             try:
