@@ -23,6 +23,7 @@ from .exceptions import IBMInputValueError
 from .ibm_backend import IBMBackend
 from .qiskit_runtime_service import QiskitRuntimeService
 from .runtime_session import RuntimeSession
+from .utils.converters import hms_to_seconds
 
 
 class Estimator(BaseEstimator):
@@ -64,12 +65,19 @@ class Estimator(BaseEstimator):
     The returned instance can be called repeatedly with the following parameters to
     estimate expectation values.
 
-    * circuit_indices: A list of circuit indices.
+    * circuits: a (parameterized) :class:`~qiskit.circuit.QuantumCircuit` or
+        a list of (parameterized) :class:`~qiskit.circuit.QuantumCircuit` or
+        a list of circuit indices.
 
-    * observable_indices: A list of observable indices.
+    * observables: a list of :class:`~qiskit.quantum_info.SparsePauliOp` or
+        a list of observable indices.
 
     * parameter_values: An optional list of concrete parameters to be bound.
 
+    * circuit_indices: (DEPRECATED) A list of circuit indices.
+
+    * observable_indices: (DEPRECATED) A list of observable indices.
+
     All the above lists should be of the same length.
 
     Example::
@@ -100,11 +108,13 @@ class Estimator(BaseEstimator):
             theta3 = [1, 2, 3, 4, 5, 6]
 
             # calculate [ <psi1(theta1)|H1|psi1(theta1)> ]
+            # pass circuits and observables as indices
             psi1_H1_result = estimator([0], [0], [theta1])
             print(psi1_H1_result)
 
             # calculate [ <psi1(theta1)|H2|psi1(theta1)>, <psi1(theta1)|H3|psi1(theta1)> ]
-            psi1_H23_result = estimator([0, 0], [1, 2], [theta1]*2)
+            # alternatively you can also pass circuits and observables as objects
+            psi1_H23_result = estimator([psi1, psi1], [H2, H3], [theta1]*2)
             print(psi1_H23_result)
 
             # calculate [ <psi2(theta2)|H2|psi2(theta2)> ]
@@ -127,25 +137,30 @@ class Estimator(BaseEstimator):
         circuits: Union[QuantumCircuit, Iterable[QuantumCircuit]],
         observables: Iterable[SparsePauliOp],
         parameters: Optional[Iterable[Iterable[Parameter]]] = None,
-        skip_transpilation: Optional[bool] = False,
         service: Optional[QiskitRuntimeService] = None,
         options: Optional[Dict] = None,
+        skip_transpilation: Optional[bool] = False,
+        transpilation_settings: Optional[Dict] = None,
+        resilience_settings: Optional[Dict] = None,
+        max_time: Optional[Union[int, str]] = None,
     ):
         """Initializes the Estimator primitive.
 
         Args:
             circuits: a (parameterized) :class:`~qiskit.circuit.QuantumCircuit` or
                 a list of (parameterized) :class:`~qiskit.circuit.QuantumCircuit`.
+
             observables: a list of :class:`~qiskit.quantum_info.SparsePauliOp`
+
             parameters: a list of parameters of the quantum circuits.
                 (:class:`~qiskit.circuit.parametertable.ParameterView` or
                 a list of :class:`~qiskit.circuit.Parameter`) specifying the order
                 in which parameter values will be bound.
-            skip_transpilation: Transpilation is skipped if set to True.
-                False by default.
+
             service: Optional instance of :class:`qiskit_ibm_runtime.QiskitRuntimeService` class,
                 defaults to `QiskitRuntimeService()` which tries to initialize your default
                 saved account.
+
             options: Runtime options dictionary that control the execution environment.
 
                 * backend: Optional instance of :class:`qiskit_ibm_runtime.IBMBackend` class or
@@ -158,6 +173,43 @@ class Estimator(BaseEstimator):
                     log levels are: ``DEBUG``, ``INFO``, ``WARNING``, ``ERROR``, and ``CRITICAL``.
                     The default level is ``WARNING``.
 
+            skip_transpilation: Transpilation is skipped if set to True. False by default.
+
+            transpilation_settings: (EXPERIMENTAL setting, can break between releases without warning)
+                Qiskit transpiler settings. The transpilation process converts
+                operations in the circuit to those supported by the backend, swaps qubits with the
+                circuit to overcome limited qubit connectivity and some optimizations to reduce the
+                circuit's gate count where it can.
+
+                * skip_transpilation: Transpilation is skipped if set to True.
+                    False by default.
+
+                * optimization_settings:
+
+                    * level: How much optimization to perform on the circuits.
+                        Higher levels generate more optimized circuits,
+                        at the expense of longer transpilation times.
+                        * 0: no optimization
+                        * 1: light optimization
+                        * 2: heavy optimization
+                        * 3: even heavier optimization
+                        If ``None``, level 1 will be chosen as default.
+
+            resilience_settings: (EXPERIMENTAL setting, can break between releases without warning)
+                Using these settings allows you to build resilient algorithms by
+                leveraging the state of the art error suppression, mitigation and correction techniques.
+
+                * level: How much resilience to build against errors.
+                    Higher levels generate more accurate results,
+                    at the expense of longer processing times.
+                    * 0: no resilience
+                    * 1: light resilience
+                    If ``None``, level 0 will be chosen as default.
+
+            max_time: (EXPERIMENTAL setting, can break between releases without warning)
+                Maximum amount of time, a runtime session can be open before being
+                forcibly closed. Can be specified as seconds (int) or a string like "2h 30m 40s".
+
         Raises:
             IBMInputValueError: If an input value is invalid.
         """
@@ -190,17 +242,31 @@ class Estimator(BaseEstimator):
             "parameters": parameters,
             "skip_transpilation": self._skip_transpilation,
         }
+        if transpilation_settings:
+            inputs.update({"transpilation_settings": transpilation_settings})
+        if resilience_settings:
+            inputs.update({"resilience_settings": resilience_settings})
         self._session = RuntimeSession(
             service=self._service,
             program_id="estimator",
             inputs=inputs,
             options=options,
+            max_time=self.calculate_max_time(max_time=max_time),
         )
 
-    def __call__(
+    def calculate_max_time(self, max_time: Optional[Union[int, str]] = None) -> int:
+        """Calculate max_time in seconds from hour minute seconds string. Ex: 2h 30m 40s"""
+        try:
+            return hms_to_seconds(max_time) if isinstance(max_time, str) else max_time
+        except IBMInputValueError as input_value_error:
+            raise IBMInputValueError(
+                "Invalid value given for max_time.", input_value_error.message
+            )
+
+    def _call(
         self,
-        circuit_indices: Sequence[int],
-        observable_indices: Sequence[int],
+        circuits: Sequence[int],
+        observables: Sequence[int],
         parameter_values: Optional[
             Union[Sequence[float], Sequence[Sequence[float]]]
         ] = None,
@@ -209,8 +275,8 @@ class Estimator(BaseEstimator):
         """Estimates expectation values for given inputs in a runtime session.
 
         Args:
-            circuit_indices: A list of circuit indices.
-            observable_indices: A list of observable indices.
+            circuits: A list of circuit indices.
+            observables: A list of observable indices.
             parameter_values: An optional list of concrete parameters to be bound.
             **run_options: A collection of kwargs passed to `backend.run()`.
 
@@ -218,8 +284,8 @@ class Estimator(BaseEstimator):
             An instance of :class:`qiskit.primitives.EstimatorResult`.
         """
         self._session.write(
-            circuit_indices=circuit_indices,
-            observable_indices=observable_indices,
+            circuit_indices=circuits,
+            observable_indices=observables,
             parameter_values=parameter_values,
             run_options=run_options,
         )
