@@ -18,7 +18,7 @@ from typing import Iterable, Union, Optional, Any, List
 from datetime import datetime as python_datetime
 
 from qiskit.qobj.utils import MeasLevel, MeasReturnType
-from qiskit.providers.backend import BackendV2 as Backend, QubitProperties
+from qiskit.providers.backend import BackendV2 as Backend
 from qiskit.providers.options import Options
 from qiskit.providers.models import (
     BackendStatus,
@@ -36,12 +36,15 @@ from qiskit.pulse.channels import (
 )
 from qiskit.transpiler.target import Target
 
+from qiskit_ibm_runtime import (  # pylint: disable=unused-import,cyclic-import
+    qiskit_runtime_service,
+)
+
 from .api.clients import AccountClient, RuntimeClient
 from .api.clients.backend import BaseBackendClient
 from .exceptions import IBMBackendApiProtocolError
 from .utils.backend_converter import (
     convert_to_target,
-    qubit_props_dict_from_props,
 )
 from .utils.converters import local_to_utc
 from .utils.backend_decoder import (
@@ -150,23 +153,25 @@ class IBMBackend(Backend):
     def __init__(
         self,
         configuration: Union[QasmBackendConfiguration, PulseBackendConfiguration],
+        service: "qiskit_runtime_service.QiskitRuntimeService",
         api_client: BaseBackendClient,
     ) -> None:
         """IBMBackend constructor.
 
         Args:
             configuration: Backend configuration.
-            api_client: IBM Quantum client used to communicate with the server.
+            service: Instance of QiskitRuntimeService.
+            api_client: IBM client used to communicate with the server.
         """
         super().__init__(
             name=configuration.backend_name,
             online_date=configuration.online_date,
             backend_version=configuration.backend_version,
         )
+        self._service = service
         self._api_client = api_client
         self._configuration = configuration
         self._properties = None
-        self._qubit_properties = None
         self._defaults = None
         self._target = None
         self._max_circuits = configuration.max_experiments
@@ -255,6 +260,15 @@ class IBMBackend(Backend):
             seed_simulator=None,
         )
 
+    @property
+    def service(self) -> "qiskit_runtime_service.QiskitRuntimeService":
+        """Return the ``service`` object
+
+        Returns:
+            service: instance of QiskitRuntimeService
+        """
+        return self._service
+
     @property
     def dtm(self) -> float:
         """Return the system time resolution of output signals
@@ -297,27 +311,6 @@ class IBMBackend(Backend):
         self._convert_to_target()
         return self._target
 
-    def qubit_properties(
-        self, qubit: Union[int, List[int]]
-    ) -> Union[QubitProperties, List[QubitProperties]]:
-        """Return QubitProperties for a given qubit.
-
-        Args:
-            qubit: The qubit to get the
-                :class:`~qiskit.provider.QubitProperties` object for. This can
-                be a single integer for 1 qubit or a list of qubits and a list
-                of :class:`~qiskit.provider.QubitProperties` objects will be
-                returned in the same order
-        """
-        self._get_properties()
-        if not self._qubit_properties:
-            self._qubit_properties = qubit_props_dict_from_props(self._properties)
-        if isinstance(qubit, int):  # type: ignore[unreachable]
-            return self._qubit_properties.get(qubit)
-        if isinstance(qubit, List):
-            return [self._qubit_properties.get(q) for q in qubit]
-        return None
-
     def properties(
         self, refresh: bool = False, datetime: Optional[python_datetime] = None
     ) -> Optional[BackendProperties]:
@@ -496,15 +489,17 @@ class IBMRetiredBackend(IBMBackend):
     def __init__(
         self,
         configuration: Union[QasmBackendConfiguration, PulseBackendConfiguration],
+        service: "qiskit_runtime_service.QiskitRuntimeService",
         api_client: Optional[AccountClient] = None,
     ) -> None:
         """IBMRetiredBackend constructor.
 
         Args:
             configuration: Backend configuration.
+            service: Instance of QiskitRuntimeService.
             api_client: IBM Quantum client used to communicate with the server.
         """
-        super().__init__(configuration, api_client)
+        super().__init__(configuration, service, api_client)
         self._status = BackendStatus(
             backend_name=self.name,
             backend_version=self.configuration().backend_version,
