@@ -24,19 +24,20 @@ if TYPE_CHECKING:
 
 @dataclass(frozen=True)
 class EstimatorResult:
-    """
-    Result of ExpectationValue
+    """Result of Estimator.
 
     .. code-block:: python
 
         result = estimator(circuits, observables, params)
 
-    where the i-th elements of `result` correspond to the expectation using the circuit and
-    observable given by `circuits[i]`, `observables[i]`, and the parameters bounds by `params[i]`.
+    where the i-th elements of ``result`` correspond to the circuit and observable given by
+    ``circuits[i]``, ``observables[i]``, and the parameter values bounds by ``params[i]``.
+    For example, ``results.values[i]`` gives the expectation value, and ``result.metadata[i]``
+    is a metadata dictionary for this circuit and parameters.
 
     Args:
-        values (np.ndarray): the array of the expectation values.
-        metadata (list[dict]): list of the metadata.
+        values (np.ndarray): The array of the expectation values.
+        metadata (list[dict]): List of the metadata.
     """
 
     values: "np.ndarray[Any, np.dtype[np.float64]]"
