@@ -22,6 +22,7 @@ from .exceptions import IBMInputValueError
 from .ibm_backend import IBMBackend
 from .qiskit_runtime_service import QiskitRuntimeService
 from .runtime_session import RuntimeSession
+from .utils.converters import hms_to_seconds
 
 
 class Sampler(BaseSampler):
@@ -59,12 +60,16 @@ class Sampler(BaseSampler):
             The default level is ``WARNING``.
 
     The returned instance can be called repeatedly with the following parameters to
-    calculate probabilites or quasi-probabilities.
+    calculate probabilities or quasi-probabilities.
 
-    * circuit_indices: A list of circuit indices.
+    * circuits: a (parameterized) :class:`~qiskit.circuit.QuantumCircuit` or
+        a list of (parameterized) :class:`~qiskit.circuit.QuantumCircuit` or a list of
+        circuit indices.
 
     * parameter_values: An optional list of concrete parameters to be bound.
 
+    * circuit_indices: (DEPRECATED) A list of circuit indices.
+
     All the above lists should be of the same length.
 
     Example::
@@ -84,12 +89,14 @@ class Sampler(BaseSampler):
 
         # executes a Bell circuit
         with Sampler(circuits=[bell], service=service, options=options) as sampler:
-            result = sampler(circuit_indices=[0], parameter_values=[[]])
+            # pass circuits as indices
+            result = sampler(circuits=[0], parameter_values=[[]])
             print(result)
 
         # executes three Bell circuits
         with Sampler(circuits=[bell]*3, service=service, options=options) as sampler:
-            result = sampler(circuit_indices=[0, 1, 2], parameter_values=[[]]*3)
+            # alternatively you can also pass circuits as objects
+            result = sampler(circuits=[bell]*3, parameter_values=[[]]*3)
             print(result)
 
         # parameterized circuit
@@ -103,7 +110,7 @@ class Sampler(BaseSampler):
         theta3 = [0, 1, 2, 3, 4, 5, 6, 7]
 
         with Sampler(circuits=[pqc, pqc2], service=service, options=options) as sampler:
-            result = sampler(circuit_indices=[0, 0, 1], parameter_values=[theta1, theta2, theta3])
+            result = sampler(circuits=[0, 0, 1], parameter_values=[theta1, theta2, theta3])
             print(result)
     """
 
@@ -111,23 +118,27 @@ class Sampler(BaseSampler):
         self,
         circuits: Union[QuantumCircuit, Iterable[QuantumCircuit]],
         parameters: Optional[Iterable[Iterable[Parameter]]] = None,
-        skip_transpilation: Optional[bool] = False,
         service: Optional[QiskitRuntimeService] = None,
         options: Optional[Dict] = None,
+        skip_transpilation: Optional[bool] = False,
+        transpilation_settings: Optional[Dict] = None,
+        resilience_settings: Optional[Dict] = None,
+        max_time: Optional[Union[int, str]] = None,
     ):
         """Initializes the Sampler primitive.
 
         Args:
             circuits: a (parameterized) :class:`~qiskit.circuit.QuantumCircuit` or
                 a list of (parameterized) :class:`~qiskit.circuit.QuantumCircuit`.
+
             parameters: A list of parameters of the quantum circuits
                 (:class:`~qiskit.circuit.parametertable.ParameterView` or
-                a list of :class:`~qiskit.circuit.Parameter`).
-            skip_transpilation: Transpilation is skipped if set to True.
-                False by default.
+                a list of :class:`~qiskit.circuit.Parameter`)
+
             service: Optional instance of :class:`qiskit_ibm_runtime.QiskitRuntimeService` class,
                 defaults to `QiskitRuntimeService()` which tries to initialize your default
                 saved account.
+
             options: Runtime options dictionary that control the execution environment.
 
                 * backend: Optional instance of :class:`qiskit_ibm_runtime.IBMBackend` class or
@@ -140,6 +151,43 @@ class Sampler(BaseSampler):
                     log levels are: ``DEBUG``, ``INFO``, ``WARNING``, ``ERROR``, and ``CRITICAL``.
                     The default level is ``WARNING``.
 
+            skip_transpilation: Transpilation is skipped if set to True. False by default.
+
+            transpilation_settings: (EXPERIMENTAL setting, can break between releases without warning)
+                Qiskit transpiler settings. The transpilation process converts
+                operations in the circuit to those supported by the backend, swaps qubits with the
+                circuit to overcome limited qubit connectivity and some optimizations to reduce the
+                circuit's gate count where it can.
+
+                * skip_transpilation: Transpilation is skipped if set to True.
+                    False by default.
+
+                * optimization_settings:
+
+                    * level: How much optimization to perform on the circuits.
+                        Higher levels generate more optimized circuits,
+                        at the expense of longer transpilation times.
+                        * 0: no optimization
+                        * 1: light optimization
+                        * 2: heavy optimization
+                        * 3: even heavier optimization
+                        If ``None``, level 1 will be chosen as default.
+
+            resilience_settings: (EXPERIMENTAL setting, can break between releases without warning)
+                Using these settings allows you to build resilient algorithms by
+                leveraging the state of the art error suppression, mitigation and correction techniques.
+
+                * level: How much resilience to build against errors.
+                    Higher levels generate more accurate results,
+                    at the expense of longer processing times.
+                    * 0: no resilience
+                    * 1: light resilience
+                    If ``None``, level 0 will be chosen as default.
+
+            max_time: (EXPERIMENTAL setting, can break between releases without warning)
+                Maximum amount of time, a runtime session can be open before being
+                forcibly closed. Can be specified as seconds (int) or a string like "2h 30m 40s".
+
         Raises:
             IBMInputValueError: If an input value is invalid.
         """
@@ -170,25 +218,39 @@ class Sampler(BaseSampler):
             "parameters": parameters,
             "skip_transpilation": self._skip_transpilation,
         }
+        if transpilation_settings:
+            inputs.update({"transpilation_settings": transpilation_settings})
+        if resilience_settings:
+            inputs.update({"resilience_settings": resilience_settings})
         self._session = RuntimeSession(
             service=self._service,
             program_id="sampler",
             inputs=inputs,
             options=options,
+            max_time=self.calculate_max_time(max_time=max_time),
         )
 
-    def __call__(
+    def calculate_max_time(self, max_time: Optional[Union[int, str]] = None) -> int:
+        """Calculate max_time in seconds from hour minute seconds string. Ex: 2h 30m 40s"""
+        try:
+            return hms_to_seconds(max_time) if isinstance(max_time, str) else max_time
+        except IBMInputValueError as input_value_error:
+            raise IBMInputValueError(
+                "Invalid value given for max_time.", input_value_error.message
+            )
+
+    def _call(
         self,
-        circuit_indices: Sequence[int],
+        circuits: Sequence[int],
         parameter_values: Optional[
             Union[Sequence[float], Sequence[Sequence[float]]]
         ] = None,
         **run_options: Any,
     ) -> SamplerResult:
-        """Calculates probabilites or quasi-probabilities for given inputs in a runtime session.
+        """Calculates probabilities or quasi-probabilities for given inputs in a runtime session.
 
         Args:
-            circuit_indices: A list of circuit indices.
+            circuits: A list of circuit indices.
             parameter_values: An optional list of concrete parameters to be bound.
             **run_options: A collection of kwargs passed to `backend.run()`.
 
@@ -196,7 +258,7 @@ class Sampler(BaseSampler):
             An instance of :class:`qiskit.primitives.SamplerResult`.
         """
         self._session.write(
-            circuit_indices=circuit_indices,
+            circuit_indices=circuits,
             parameter_values=parameter_values,
             run_options=run_options,
         )
