@@ -18,7 +18,7 @@ import os
 import re
 from queue import Queue
 from threading import Condition
-from typing import List, Optional, Any, Dict, Union, Tuple
+from typing import List, Optional, Any, Dict, Union, Tuple, Type
 from urllib.parse import urlparse
 
 import requests
@@ -26,6 +26,25 @@ from ibm_cloud_sdk_core.authenticators import IAMAuthenticator
 from ibm_platform_services import ResourceControllerV2
 
 
+def validate_job_tags(
+    job_tags: Optional[List[str]], exception: Type[Exception]
+) -> None:
+    """Validates input job tags.
+
+    Args:
+        job_tags: Job tags to be validated.
+        exception: Exception to raise if the tags are invalid.
+
+    Raises:
+        Exception: If the job tags are invalid.
+    """
+    if job_tags and (
+        not isinstance(job_tags, list)
+        or not all(isinstance(tag, str) for tag in job_tags)
+    ):
+        raise exception("job_tags needs to be a list of strings.")
+
+
 def get_iam_api_url(cloud_url: str) -> str:
     """Computes the IAM API URL for the given IBM Cloud URL."""
     parsed_url = urlparse(cloud_url)
