@@ -16,6 +16,8 @@ from unittest import SkipTest
 
 from qiskit.transpiler.target import Target
 
+from qiskit_ibm_runtime import QiskitRuntimeService
+
 from ..ibm_test_case import IBMIntegrationTestCase
 from ..decorators import run_integration_test
 
@@ -60,6 +62,12 @@ class TestIBMBackend(IBMIntegrationTestCase):
                 simulator=False, min_num_qubits=5, instance=cls.dependencies.instance
             )
 
+    def test_backend_service(self):
+        """Check if the service property is set."""
+        backend = self.backend
+        with self.subTest(backend=backend.name):
+            self.assertIsInstance(backend.service, QiskitRuntimeService)
+
     def test_backend_target(self):
         """Check if the target property is set."""
         backend = self.backend
@@ -73,6 +81,14 @@ class TestIBMBackend(IBMIntegrationTestCase):
         with self.subTest(backend=backend.name):
             self.assertIsNotNone(backend.max_circuits)
 
+    def test_backend_qubit_properties(self):
+        """Check if the qubit properties are set."""
+        backend = self.backend
+        with self.subTest(backend=backend.name):
+            if backend.simulator:
+                raise SkipTest("Skip since simulator does not have qubit properties.")
+            self.assertIsNotNone(backend.qubit_properties(0))
+
     def test_backend_simulator(self):
         """Test if a configuration attribute (ex: simulator) is available as backend attribute."""
         backend = self.backend
@@ -90,7 +106,7 @@ class TestIBMBackend(IBMIntegrationTestCase):
         """Check the properties of calibration of a real chip."""
         backend = self.backend
         with self.subTest(backend=backend.name):
-            if backend.configuration().simulator:
+            if backend.simulator:
                 raise SkipTest("Skip since simulator does not have properties.")
             self.assertIsNotNone(backend.properties())
 
@@ -98,9 +114,9 @@ class TestIBMBackend(IBMIntegrationTestCase):
         """Check the backend pulse defaults of each backend."""
         backend = self.backend
         with self.subTest(backend=backend.name):
-            if backend.configuration().simulator:
+            if backend.simulator:
                 raise SkipTest("Skip since simulator does not have defaults.")
-            if not backend.configuration().open_pulse:
+            if not backend.open_pulse:
                 raise SkipTest("Skip for backends that do not support pulses.")
             self.assertIsNotNone(backend.defaults())
 
