@@ -13,7 +13,7 @@
 """Tests for job functions using real runtime service."""
 
 import uuid
-
+from datetime import datetime, timezone
 from qiskit.providers.jobstatus import JobStatus
 
 from ..ibm_test_case import IBMIntegrationJobTestCase
@@ -127,6 +127,42 @@ class TestIntegrationRetrieveJob(IBMIntegrationJobTestCase):
         self.assertEqual(program_id, rjobs[0].program_id)
         self.assertEqual(1, len(rjobs), f"Retrieved jobs: {[j.job_id for j in rjobs]}")
 
+    @run_integration_test
+    def test_retrieve_jobs_by_job_tags(self, service):
+        """Test retrieving jobs by job_tags."""
+        job_tags = ["test_tag"]
+        job = self._run_program(service, job_tags=job_tags)
+        job.wait_for_final_state()
+        rjobs = service.jobs(job_tags=job_tags)
+        self.assertEqual(1, len(rjobs), f"Retrieved jobs: {[j.job_id for j in rjobs]}")
+        rjobs = service.jobs(job_tags=["no_test_tag"])
+        self.assertFalse(rjobs)
+
+    @run_integration_test
+    def test_retrieve_jobs_by_session_id(self, service):
+        """Test retrieving jobs by session_id."""
+        job = self._run_program(service, start_session=True)
+        job.wait_for_final_state()
+        job_2 = self._run_program(service, session_id=job.job_id)
+        job_2.wait_for_final_state()
+        rjobs = service.jobs(session_id=job.job_id)
+        self.assertEqual(2, len(rjobs), f"Retrieved jobs: {[j.job_id for j in rjobs]}")
+        rjobs = service.jobs(session_id="test")
+        self.assertFalse(rjobs)
+
+    @run_integration_test
+    def test_jobs_filter_by_date(self, service):
+        """Test retrieving jobs by creation date."""
+        current_time = datetime.now(timezone.utc)
+        job = self._run_program(service)
+        job.wait_for_final_state()
+        time_after_job = datetime.now(timezone.utc)
+        rjobs = service.jobs(created_before=time_after_job, created_after=current_time)
+        self.assertTrue(job.job_id in [j.job_id for j in rjobs])
+        for job in rjobs:
+            self.assertTrue(job.creation_date <= time_after_job)
+            self.assertTrue(job.creation_date >= current_time)
+
     @run_integration_test
     def test_jobs_filter_by_hgp(self, service):
         """Test retrieving jobs by hgp."""
@@ -145,3 +181,19 @@ class TestIntegrationRetrieveJob(IBMIntegrationJobTestCase):
         fake_hgp = f"{uuid_}/{uuid_}/{uuid_}"
         rjobs = service.jobs(program_id=program_id, instance=fake_hgp)
         self.assertFalse(rjobs)
+
+    @run_integration_test
+    def test_retrieve_jobs_sorted_by_date(self, service):
+        """Test retrieving jobs sorted by the date."""
+        job = self._run_program(service)
+        job.wait_for_final_state()
+        job_2 = self._run_program(service)
+        job_2.wait_for_final_state()
+        rjobs = service.jobs()
+        rjobs_desc = service.jobs(descending=True)
+        rjobs_asc = service.jobs(descending=False)
+        self.assertTrue(rjobs[0], rjobs_asc[1])
+        self.assertTrue(rjobs[1], rjobs_asc[0])
+        self.assertEqual(
+            [job.job_id for job in rjobs], [job.job_id for job in rjobs_desc]
+        )
