@@ -39,6 +39,7 @@ from ..ibm_test_case import IBMTestCase
 from ..account import (
     get_account_config_contents,
     temporary_account_config_file,
+    custom_qiskitrc,
     no_envs,
     custom_envs,
 )
@@ -816,6 +817,24 @@ class TestEnableAccount(IBMTestCase):
         self.assertTrue(service._account)
         self.assertEqual(service._account.instance, instance)
 
+    def test_enable_account_by_qiskitrc(self):
+        """Test initializing account by a qiskitrc file."""
+        token = "token-x"
+        proxies = {"urls": {"https": "localhost:8080"}}
+        str_contents = f"""
+        [ibmq] 
+        token = {token}
+        url = https://auth.quantum-computing.ibm.com/api 
+        verify = True
+        default_provider = ibm-q/open/main
+        proxies = {proxies}
+        """
+        with custom_qiskitrc(contents=str.encode(str_contents)):
+            with temporary_account_config_file(contents={}):
+                service = FakeRuntimeService()
+        self.assertTrue(service._account)
+        self.assertEqual(service._account.token, token)
+
     def test_enable_account_by_channel_input_instance(self):
         """Test initializing account by channel and input instance."""
         instance = uuid.uuid4().hex
